package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````_"````````!``````````-"Q````
M````!0```$``.``+`$``&@`9``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```#,`@``````
M`,P"````````S`(````````A`````````"$``````````0`````````#``!P
M!````&NP`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````))P`````
M```DG``````````0`````````0````8```!XJP```````'BK````````>*L`
M``````#8!``````````%`````````!`````````"````!@```)"K````````
MD*L```````"0JP```````"`"````````(`(````````(``````````0````$
M````J`(```````"H`@```````*@"````````)``````````D``````````0`
M````````!`````0````$G`````````2<````````!)P````````@````````
M`"``````````!`````````!0Y71D!````&B3````````:),```````!HDP``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!XJP```````'BK````````>*L```````"(!````````(@$`````````0``
M```````$````%`````,```!'3E4`&TOZ`-DQ%V0R(Z`RP;<'?MIOID$O;&EB
M+VQD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0`````[````1P````0````(
M````()`0`05`!,0H`@$$@(8$A(*)``()(`0(B(`00;H``HA'````2````$D`
M``!+````````````````````3`````````!-````3P```%``````````````
M`%$```!2`````````````````````````%,```!4````50````````!6````
M5P``````````````6`````````!9````````````````````6@```%L`````
M````70````````!>`````````%\`````````````````````````````````
M``!@````````````````````80````````!B````````````````````9```
M`!E^"H=_J9R;:@E#UC_/TFPA_^0.#3J7"W)0G]C#Y3\LB0=PT]EQ6!RM2^/`
M:QJ>4-5DU'R93\.;+\6;MC-BV^W_8?)A:W^:?+OCDGRS`8MO0OK7AT-%U>QG
MK\QF%8PES*/@^TG/WD<MXT?&`>"G`@IOQ=\?^Z%L8```````````````````
M`````````````````````````P`+`%`?``````````````````#G`@``$0``
M``````````````````````"E`@``$@````````````````````````!]`0``
M$@````````````````````````"%````$@`````````````````````````,
M`@``$@````````````````````````",`@``$@``````````````````````
M``#)`0``$@````````````````````````"N````$@``````````````````
M``````"%`@``$@````````````````````````"D````$@``````````````
M``````````!(`@``$@````````````````````````#6`0``$@``````````
M``````````````!]````$0````````````````````````"5````$@``````
M``````````````````"P`0``$@````````````````````````#7`@``$@``
M``````````````````````#\`0``$@`````````````````````````A`0``
M$@````````````````````````"A`0``$@````````````````````````#3
M````$@````````````````````````##````$@``````````````````````
M``!8````$@`````````````````````````!````(```````````````````
M```````8`0``$@````````````````````````"]`@``$@``````````````
M```````````=````(`````````````````````````".````$@``````````
M``````````````#*````$@````````````````````````"O`@``$@``````
M``````````````````"3`0``$@````````````````````````![````$0``
M``````````````````````#9````%@````````````````````````!;`0``
M$@````````````````````````#L````$@````````````````````````"$
M`0``$@````````````````````````!%`0``$@``````````````````````
M``!;`@``$@````````````````````````#"`0``$@``````````````````
M```````'`0``$@````````````````````````#(`@``$@``````````````
M``````````"U`0``$@`````````````````````````V`0``$@``````````
M``````````````"J`@``$@````````````````````````!O`0``$@``````
M``````````````````#0`0``$@````````````````````````"7`@``$@``
M``````````````````````!V`0``$@`````````````````````````O`0``
M$@````````````````````````":`0``$0`````````````````````````M
M`@``$@````````````````````````"+`0``$@``````````````````````
M``"-````$@````````````````````````!)````(@``````````````````
M```````8`@``$@````````````````````````!3`0``$@``````````````
M``````````"]`0``$@````````````````````````#@`@``$@``````````
M``````````````!Y`@``$@````````````````````````#G`0``$@``````
M``````````````````"J`P``$@````````````````````````!L`@``$0``
M``````````````````````"U````$@````````````````````````#\````
M$@`````````````````````````Y`@``$@`````````````````````````W
M````$@````````````````````````"<````$@``````````````````````
M``!B`0``$@````````````````````````!J````$@``````````````````
M``````#U`0``$@````````````````````````#V`P``$`#Q_P"X````````
M``````````"8`P``$@`+`/9%````````'`````````#:`P``$``5``"P````
M``````````````#G`P``$``5``"P``````````````````!K!```$@`+`+(]
M````````M`$```````#<`P``(``5``"P```````````````````3!```$``5
M`%"P```````````````````C!```$@`+`+(\````````-@````````!X!```
M$0`5`$BP````````"``````````K!```$``6`%"P``````````````````#+
M`P``$0`,`/!1````````!`````````".`P``$@`+`!Q0````````N@$`````
M``!(`P``$@`+`"A,````````X`$```````""!```$@`+`(!$````````5```
M```````J`P``$@`+`*(]````````$`````````#@`P``$@`+`/P@````````
M(@````````"_`P``$``6`'BP``````````````````!$````$@`+`%`?````
M````K`$```````!`!```$``6`'BP``````````````````!>`P``$@`+`"9$
M````````6@`````````(!```$@`+`!I/`````````@$```````!2!```$``5
M`%"P``````````````````""`P``$@`+`(X_````````\@`````````W!```
M$@`+`+Y.````````7`````````"*!```$@`+`(!`````````I@,```````!%
M!```$@`+`.1&````````1`4````````[`P``$@`+`&8_````````*```````
M``!L`P``$@`+`.@\````````N@````````"S`P``$@`+``A.````````M@``
M``````!9!```$@`+`!)&````````T@``````````7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C
M7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`
M7U]S=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C
M8V5S<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U
M;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?
M1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI
M;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M96UM
M;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR`'-T
M<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`;65M8W!Y`'-T9&5R<@!?7W9F
M<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!M96UC;7``9V5T=6ED`&UK
M9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R
M;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]P87)S90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L
M7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`
M;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\`;&EB8RYS;RXV
M`&QD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?
M0E-37T5.1%]?`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7T1!5$%?
M0D5'24Y?7P!?7V=L;V)A;%]P;VEN=&5R)`!S:&%?=7!D871E`%]?4T1!5$%?
M0D5'24Y?7P!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,S0`
M1TQ)0D-?,BXS,P!'3$E"0U\R+C(W`"]U<W(O;&EB+W!E<FPU+S4N-#`O8V]R
M95]P97)L+T-/4D4````````"``$``P`#``$``0`#``,``P`#``$``P`#``,`
M`P`!``$``0`#``,``P`#``$``P`!``$`!``#``$``P`#``$``P`!``,``P`!
M``,``0`!``,``0`#``,``P`!``,``P`#``$``P`$``,``0`#``,``P`!``,`
M`P`!``,``0`!``4``P`#``,``P`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``P`$`P``
M$````$````"TD98&```%`)<$```0````LY&6!@``!`"B!```$````(>1E@8`
M``,`K00````````!``$`#@,``!``````````AY&6!@```@"M!````````'BK
M`````````P`````````>(0```````("K`````````P````````#>(0``````
M`(BK`````````P````````"@(0```````*"O`````````P`````````H3```
M`````/"O`````````P````````!(L````````/BO`````````P````````!0
M'P````````"P`````````P``````````L````````!BP`````````P``````
M``!04P```````""P`````````P`````````HDP```````"BP`````````P``
M```````PDP```````#"P`````````P`````````XDP```````#BP````````
M`P````````!`DP```````$BP`````````P````````"X50```````)"O````
M`````@````(``````````````)BO`````````@````P``````````````*BO
M`````````@````X``````````````+"O`````````@```!@`````````````
M`+BO`````````@```!L``````````````,"O````````"P```"$`````````
M`````,BO`````````@```",``````````````-"O`````````@```"8`````
M`````````-BO`````````@```#(``````````````."O`````````@```#8`
M`````````````.BO`````````@```#X``````````````,"M````````!0``
M``,``````````````,BM````````!0````0``````````````-"M````````
M!0````4``````````````-BM````````!0````8``````````````."M````
M````!0````<``````````````.BM````````!0````@``````````````/"M
M````````!0````D``````````````/BM````````!0````H`````````````
M``"N````````!0````L```````````````BN````````!0````T`````````
M`````!"N````````!0````\``````````````!BN````````!0```!``````
M`````````""N````````!0```!$``````````````"BN````````!0```!(`
M`````````````#"N````````!0```!,``````````````#BN````````!0``
M`!0``````````````$"N````````!0```!4``````````````$BN````````
M!0```!8``````````````%"N````````!0```!<``````````````%BN````
M````!0```!D``````````````&"N````````!0```!H``````````````&BN
M````````!0```!P``````````````'"N````````!0```!T`````````````
M`'BN````````!0```!X``````````````("N````````!0```!\`````````
M`````(BN````````!0```"(``````````````)"N````````!0```"0`````
M`````````)BN````````!0```"4``````````````*"N````````!0```"<`
M`````````````*BN````````!0```"@``````````````+"N````````!0``
M`"D``````````````+BN````````!0```"H``````````````,"N````````
M!0```"L``````````````,BN````````!0```"P``````````````-"N````
M````!0```"T``````````````-BN````````!0```"X``````````````."N
M````````!0```"\``````````````.BN````````!0```#``````````````
M`/"N````````!0```#$``````````````/BN````````!0```#,`````````
M``````"O````````!0```#0```````````````BO````````!0```#4`````
M`````````!"O````````!0```#<``````````````!BO````````!0```#@`
M`````````````""O````````!0```#D``````````````"BO````````!0``
M`#H``````````````#"O````````!0```#L``````````````#BO````````
M!0```#P``````````````$"O````````!0```#T``````````````$BO````
M````!0```#\``````````````%"O````````!0```$```````````````%BO
M````````!0```$$``````````````&"O````````!0```$(`````````````
M`&BO````````!0```$,``````````````'"O````````!0```$0`````````
M`````'BO````````!0```$4``````````````("O````````!0```$8`````
M`````````)>3```S`\-!`[X#(1,#0_V3@@,A$U,3`(.R@@!G``X`%YX```,^
M#B!G`PX`$P```!>>```#/HX?9P,.`!,````7G@```SX.'V<##@`3````%YX`
M``,^CAYG`PX`$P```!>>```#/@X>9P,.`!,````7G@```SZ.'6<##@`3````
M%YX```,^#AUG`PX`$P```!>>```#/HX<9P,.`!,````7G@```SX.'&<##@`3
M````%YX```,^CAMG`PX`$P```!>>```#/@X;9P,.`!,````7G@```SZ.&F<#
M#@`3````%YX```,^#AIG`PX`$P```!>>```#/HX99P,.`!,````7G@```SX.
M&6<##@`3````%YX```,^CAAG`PX`$P```!>>```#/@X89P,.`!,````7G@``
M`SZ.%V<##@`3````%YX```,^#A=G`PX`$P```!>>```#/HX69P,.`!,````7
MG@```SX.%F<##@`3````%YX```,^CA5G`PX`$P```!>>```#/@X59P,.`!,`
M```7G@```SZ.%&<##@`3````%YX```,^#A1G`PX`$P```!>>```#/HX39P,.
M`!,````7G@```SX.$V<##@`3````%YX```,^CA)G`PX`$P```!>>```#/@X2
M9P,.`!,````7G@```SZ.$6<##@`3````%YX```,^#A%G`PX`$P```!>>```#
M/HX09P,.`!,````7G@```SX.$&<##@`3````%YX```,^C@]G`PX`$P```!>>
M```#/@X/9P,.`!,````7G@```SZ.#F<##@`3````%YX```,^#@YG`PX`$P``
M`!>>```#/HX-9P,.`!,````7G@```SX.#6<##@`3````%YX```,^C@QG`PX`
M$P```!>>```#/@X,9P,.`!,````7G@```SZ."V<##@`3````%YX```,^#@MG
M`PX`$P```!>>```#/HX*9P,.`!,````7G@```SX."F<##@`3````%YX```,^
MC@EG`PX`$P```!>>```#/@X)9P,.`!,````7G@```SZ."&<##@`3````%YX`
M``,^#@AG`PX`$P```!>>```#/HX'9P,.`!,````7G@```SX.!V<##@`3````
M%YX```,^C@9G`PX`$P```!>>```#/@X&9P,.`!,````7G@```SZ.!6<##@`3
M````%YX```,^#@5G`PX`$P```!>>```#/HX$9P,.`!,````7G@```SX.!&<#
M#@`3````'7&&[*+HRN"`$*;D3OQ2^*J'%YD```,YZ0(C.+3Z(S3$^I,%!/L3
M!H3Z$P7$^R,N]/J#-PD`(S3T_(%'[_!?]A>6```#-H8`LH47E0```S5E`^\P
M0".7EP``@[<G!(/'!P!CA0<.EY<``(.WIP"7E```DX2D"9*7F&.#*<3[@T>G
M2QN%20`.!9/G-P`C#?=*[_`?[(,U!/N7EP``@[>'`)!C`[@%`(,GQ/NJAA<W
M```3!T=;%S4``!,%15J8[I3D([`&`8CFD.H%1XTI8UGW#*$%&X4W`!%'D&&3
M%S<`MI<%)Y#CH07C&:?^#@>(;#:7(S`'`$Z&`4>7)0``DX6%EN_P'[LUR8AL
M$PI$_._P7]JJB=*%%S4``!,%Q2?O$"!P)<&(;._PW[3O\)_+`S>$_(,W"0"Y
MCP%'I>OF8$9DIF0&:4)Z3H7B>25A@H#O\%_&EY0``).$A/N(["'%[_!?SY>7
M``"#MP?QA68SAT<`&&,VER,+!Y(!MXAL[_!_NV&WB&@!Q>\@4%-IO]*%%S4`
M`!,%Q1CO$*!HB.A!U>6W$4>IMP5%[_#?M^_PG^/O`"`"JH<7E0```S5E[X)E
M,``3<0'_@48!1PJ([_"?W@*0EY$``).!(6Z"@`$`01$BX`;D``@7E0``$P7E
M\9>7``"3AV?Q8XNG`)>7``"#MZ?FB<<"9*)@00&"AZ)@`F1!`8*`%Y4``!,%
M!>^7E0``DX6%[HF-01&3US5`_9$BX`;D``B^E86%D<F7EP``@[<GXXG'`F2B
M8$$!@H>B8`)D00&"@)>7``"#QP?KE>M!$2+@!N0`")>7``"#M^?BD<<7E0``
M`S5%Y(*7[_!?]J)@`F2%1Q>7```C`/?H00&"@(*`01$BX`;D``@"9*)@00&5
MOQ,!`=0C.($J@`4C/!$J(S21*B,P(2LC/#$IEY,``(.S@]B3!H34P6Z3"(4#
MDP^%!X.W`P`C-/3\@4<VB)..#O`W#_\``[8(`*$(00B3508"$Q>&`1.3A0&3
M$H8`DU>&`@(7$UZ&`)-4A@,!DP(3L_+B`;/WUP$34P,",V=7`#-^W@&B!<6/
M,V?'`1M6A@&S]>4!L^=G`%&/S8\C..C^(SSX_N.1^/L#/P3;@SZ$VP,W!-P#
M/H35`S,$UH,XA-8#.`37@S6$UX,_!-B3A`8@$:"RC[!BG&*Z@J$&L8^SQ^<!
ML\?'`1.7%P#]@UV/`A<!D[C^&HYVCT:#EH["B"Z(_H7CF-3\$&$,:8,XA0`#
M.(4!@S:$U`,S!0*35[8!$Q=6`#>.@EH3#IZ978_REK/'!0$3WR@``A>3GN@!
MFI:S[NX!`9.S]Q<!-I>SQP<!@S8$U1.?#@(37P\"/I<"%[/'Y0$!D_&/\I:3
M4K<!DQ]7`*V/PI:S[U\`MI>34B8`_I>3%N8!@S^$U;/F5@"SSMX`@A>!D[/^
M[@#RGY/4MP&NGY.25P"SSNX!L^*2`/Z>EIZ3'^<!@S($U@F#,^?O`((>DY\&
M`KF.D]X.`I/?#P+RDOV.%I^3U+X!DY)>`+/&]@'ZEC/OD@#ZEI.2YP$#/X36
MB8.SY_(`@A:3$@<"/8^!DI/2`@)RGS-WUP%^GY/4M@&3GU8`,T=7`'J7,^^?
M`'J7@S\$UQ.?[@&3WBX`,V_?`1.9!P("%[/'YP$!DQ-9"0*SCL\!]8^6GI,?
M5P"34K<!L\<G`?:7L^Y?`/:7@S*$UY/>)@"3G^8!L^_?`;-&_P&3%`\"@A>!
MDX&0LX["`?F.RIX3GU<`D]*W`:6.]I:S;E\`]I:#,@38DUXG`!,?YP$S;]\!
M,\?O`1.9#P*"%H&2$UD)`K..P@%]CZ:>DY]6`)/2M@$S1R<!=I>S[E\`=I>#
M/X38D]XG`).2YP&SXM(!LT=?`),4#P("%P&3@9"SCL\!]8_*GA,?5P"37[<!
MI8_VE[-N_P'VEP,_!-F3WB8`DY_F`;/OWP&SQO(!$YD"`H(7@9,360D"LP[/
M`?F.IIX3GU<`D]*W`;/&)@'VEK-N7P#VEH,RA-F37B<`$Q_G`3-OWP$SQ^\!
MDY0/`H(6@9*!D+..P@%]C\J>DY]6`)/2M@$ECW:7L^Y?`':7@S($VI/>)P"3
MG^<!L^_?`;-'_P$3&0\"`A<!DQ-9"0*SCL(!]8^FGA,?5P"34K<!L\<G`?:7
MLVY?`/:7@S*$VI/>)@`3G^8!,V_?`;/&[P&3E`\"@A>!DX&0LX["`?F.RIZ3
MGU<`D]*W`:6.]I:S[E\`]I:#,@3;DUXG`),?YP&S[]\!,T?_`1,9#P*"%H&2
M$UD)`K..P@%]CZ:>$Y]6`)/2M@$S1R<!=I>S;E\`=I>#,H3;D]XG`!.?YP$S
M;]\!L\?O`9.4#P("%P&3@9"SCL(!]8_*GI,?5P"34K<!I8_VE[/N7P#VEX,R
M!-R3WB8`DY_F`;/OWP&S1O\!DQD/`H(7@9.3V0D"LX["`?F.IIX3GU<`D]*W
M`;/&-@'VEK-N7P"#-(3<]I:3$N<!DUXG`+/BT@$SQU\`$Y\&`A.9#P(37P\"
M$UD)`K.&Q`%]C\Z6DQY?`)-?OP$S1R<!-I>SYOX!@S0$W3:7D]\G`).6YP&S
MYO8!L\?2`),>!P*3GP("D]X.`C.'Q`&3WP\"L_?G`4J7DY)>`)/4O@&SQ_<!
MNI<SYY(`NI>#-(3=$Q?O`8(7$U\O`(&3,V?G`1/9MP&3D@8"$Y]7`+F.\I23
MT@(",V\O`;/VU@&FG[/&5@`"'Q-?#P+^EOJ6`SD$WI.?[@$3GP8"D]XN`!-?
M#P*S[M\!DQ1?`'*9DQ\'`A->OP$S1]<!D]\/`C/NQ`%]C\J2,T?W`0(>$UX.
M`A:7DY+G`8F#<I>SXO(`L\=>``,YA-Z3%`<"@9"UC[?VV6Z3AA:ZD]FT`1.>
M5``VF3-N/@&"%\J?@9,"'OZ7$UX.`CZ>DQ_O`1-?+P"S[^\!@S<$WQ,9#@(3
M60D",\_R`9-9N0$S3^\`@AX3%UD`D]X.`C-G-P&VEP(?$U\/`O:7`A?ZEP&3
M/I>3GN0!B8"S[IX`@S>$WY,9!P*3V0D",\_?`9/4N0$S3\\!@A(3GED`D]("
M`C-NG@"VEP(?$U\/`I:7`A[ZEQ->#@(^GA,?Z0$362D`,V\O`8,W!."3$@X"
MD]("`K/$[@$3V;(!N8R"'Q.74@"3WP\",V<G`;:7@A2!D/Z7`A>FEP&3/I>3
MG^D!D]DI`+/O/P&#-X3@DQ0'`H&0,TG_`9/9M`$S2<D!@AX3GE0`D]X.`C-N
M/@&VEP(9$UD)`O:7`A[*EQ->#@(^GI.>X@&3TB(`L^Y>`(,W!.$3&0X"$UD)
M`K/"WP&36;D!L\+B``(?$Q=9`!-?#P(S9S<!MI>"$I/2`@+ZEP(7EI<!DSZ7
M$Y_D`8F`,V^?`(,WA.&3$@<"D]("`K/$[@&3V;(!L\3$`8(?$YY2`)/?#P(S
M;CX!MI>"%(&0_I<"'J:7$UX.`CZ>DQ_I`1-9*0"#-P3BL^\O`9,4#@*!D#-)
M_P&3V;0!,TGI`((>$Y=4`)/>#@(S9S<!MI<"&1-9"0+VEP(7RI<!DSZ7DY[B
M`9/2(@"S[EX`@S>$XA,9!P(360D"L\+?`9-9N0&SPL(!`A\3'ED`$U\/`C-N
M/@&VEX(2D]("`OJ7`AZ6EQ->#@(^GA.?Y`&)@#-OGP"#-P3CDQ(.`I/2`@*S
MQ.X!D]FR`;F,@A\3EU(`D]\/`C-G-P&VEX(4@9#^EP(7II<!DSZ7DQ_I`1-9
M*0"S[R\!@S>$XY,4!P*!D#-)_P&3V;0!,TG)`8(>$YY4`)/>#@(S;CX!MI<"
M&1-9"0+VEP(>RI<37@X"/IZ3GN(!D](B`+/N7@"#-P3D$QD.`A-9"0*SPM\!
MDUFY`;/"X@`"'Q,760`37P\",V<W`;:7@A*3T@("^I<"%Y:7`9,^EQ.?Y`&)
M@#-OGP"#-X3DDQ('`I/2`@*SQ.X!D]FR`;/$Q`&"'Q.>4@"3WP\",VX^`;:7
M@A2!D/Z7`AZFEQ->#@(^GI,?Z0$362D`L^\O`8,W!.63%`X"@9`S2?\!D]FT
M`3-)Z0""'A.75`"3W@X",V<W`;:7`AD360D"]I<"%\J7`9,^EY.>X@&3TB(`
ML^Y>`(,WA.43&0<"$UD)`K/"WP&36;D!L\+"`0(?$QY9`!-?#P(S;CX!MI>"
M$I/2`@+ZEP(>EI<37@X"/IX3G^0!B8`S;Y\`@S<$YI,9#@*3V0D"L\+N`9/4
MN0&SPN(`@A\3EUD`D]\/`D6/MI>"$I/2`@+^EP(7EI<!DSZ7DQ_I`1-9*0"S
M[R\!@S>$YI,4!P*!D+-"_P$3V;0!L\+"`8(>$YY4`)/>#@(S;BX!MI>"$I/2
M`@+VEP(>EI<37@X"LX['`9.2Z0&3V2D`L^(R`8,W!.<3F0X"$UD)`C/.7P"3
M6;D!,T[N``(?$Q=9`!-?#P(S9S<!MI<"'A->#@+ZEP(7`9,3G^0!\I>)@#-O
MGP`SCN<``S>$Y[/'X@&SQ]<!DQ0.`H(?@9"3WP\"-I>"%Y.>5`"3V;0!@9-^
MESZ7DQ_I`;/G/@$362D`L^\O`3Z7@S<$Z#-)_P&3'@<",T[)`8(2D]X.`I/2
M`@*VEP(>$UX.`I:7DY9>`)/2O@&SYE8`$Y?D`?*7B8"#,H3H18^VE[?VQB.3
M%`<"$YX'`I.7)@"3A\?-@9"SYN\`$QD/`A->#@(SC_(`$UD)`K/RGP"S]M8!
M2I^SYE8`$UF^`9,27@#ZEC/O(@'ZE@,Y!.D3G^X!D]XN`#-OWP&3D@\",V?G
M`9.?!@*3WP\"LW:?`+,.^0"3T@(",W?'`9:>$]F_`9.27P!5CW:7DQ;N`;/N
M(@$37BX`L^;&`7:7@SZ$Z9.2!@*3T@(",V[?``(7`9,S>5\`OIXS?OX!IIXS
M;BX!DQ17`!-9MP%VGK/N)`%VG@,Y!.J3GN\!D]\O`+/N_@&3%`X"L^;6`0(?
M@9"S_UX`,P[Y`!-?#P+YCGJ>L^;V`9/9M`&3GU0`$QGG`1-?)P`SA\8!LV;I
M`3/N/P$#/X3J<I>3GP8"D]\/`C/NW@`"%P&3,_G^`3Z?,WZ>`!:?,VXN`9,2
M5P`36;<!>IXS[R(!>IX#.03K$Y_D`8F`,V^?`),2#@*SYN8!@AZ3T@("LW3_
M`3,.^0"3W@X"^8YVGL6.D]FR`9.44@`3&><!DUXG`#.'Q@&S9MD!,^XT`8,^
MA.MREY.4!@*!D#-NWP`"%P&3,WF?`+Z>,WY>`/Z>,VXN`9,?5P`36;<!=IZS
M[B\!=IX#.03LDY[B`9/2(@"S[EX`DQ\.`K/FU@$"'Y/?#P*S\IX`,P[Y`!-?
M#P+YCGJ>L^96`)/9OP&3DE\`$QGG`1-?)P`SA\8!LV;I`3/N,@$#/X3L<I>3
MD@8"D]("`C/NW@`"%P&3,_E>`#Z?,W[^`2:?,VXN`9,45P`36;<!>IXS[R0!
M>IX#.03M$Y_O`9/?+P`S;_\!DQ0.`K/FY@&"'H&0LW]?`#,.^0"3W@X"^8YV
MGK/F]@&3V;0!DY]4`!,9YP&37B<`,X?&`;-FV0$S[C\!@SZ$[7*7DY\&`I/?
M#P(S;M\``A<!DS-Y_P&^GC-^G@"6GC-N+@&3$E<`$UFW`7:>L^XB`7:>`SD$
M[I.>Y`&)@+/NG@"3$@X"L^;6`0(?D]("`K/T_@$S#OD`$U\/`OF.>I[%CI/9
ML@&3E%(`$QGG`1-?)P`SA\8!,^XT`;-FZ0&#-(3N<I<3GP8"$U\/`C/NW@`"
M%P&3,_GN`;Z4,WY>`*:?,VXN`9,45P`36;<!?IZS[R0!?IX#.03ODY_B`9/2
M(@"S[U\`DQ0.`K/F]@&"'H&0L_+O`3,.^0"3W@X"^8YVGK/F5@"3V;0!DY)4
M`!,9YP&37B<`,X?&`3/N,@&S9MD!@S*$[W*7DYX&`I/>#@(S[M\``A<!DS/Y
MWP&^DC-^G@`6GS-N+@&3$E<`$UFW`7J>,^\B`7J>`SD$\!.?Y`&)@#-OGP"3
M$@X"L^;F`8(?D]("`K-TWP$S#OD`D]\/`OF.?IX3V;(!DY]2`,6.DQ3G`0F#
M18_REH,TA/`S[B\!\I:3'P<"D]\/`C-N[P""%H&2,WG_`;Z4,WY>`*:>,VXN
M`9.45@`3V;8!=IZS[B0!=IZ#-`3Q$YGB`9/2(@"3'@X",VY9`#-GQP$"'Y/>
M#@*S@O0`=8^S=/X!$U\/`A:?18^3DEX`D]2^`7J7,^^2``,YA/%ZEQ.?Y@&)
M@K-FWP`"%P&3DY(&`I/2`@(S;]X`DUFW`3Z9DQ17`,J?L^0T`3-Y7@`S?]\!
M,V\O`8(4@9!^GP,Y!/(FGY,?#P*3WP\"DY3N`9/>+@"S[M0!/IF3E%\`D]>_
M`;/FU@'=C`(>L_?F`!->#@*3E@0"L_1>`$J>Q8_REX&2OI:3%.<!"8/9C(,Y
MA/(3F08"M[>8,A-9"0(SQYX`B@>3AV<=,T?G`1,>60`37[D!,V[N`0(7,X_Y
M`!:?`9,"'GJ7$UX.`CJ>$Y_O`1/7+P"S;^\`DQ(.`@,_!/.3T@(",\?T`9/9
ML@$UCX(>DY92`#Z?L^8V`9/>#@("%_J>`9."%G:7@9*ZEI,>Z0$35RD`L^[N
M`!.9!@(#-X3S$UD)`C//WP&36;D!,T_/`8(4$QY9`(&0,VX^`3Z7`A\37P\"
M)I<"'GJ7$UX.`CJ>$Y_B`9/2(@`S;U\`DQ0.`@,W!/2!D+/"[@&3V;0!L\+2
M`((?DY94`)/?#P*SYC8!/I>"$I/2`@)^EX(6%I>!DKJ6DQ_I`1-9*0"S[R\!
MDY(&`@,WA/23T@(",TG_`9/9L@$S2<D!@AX3GE(`D]X.`C-N/@$^EP(9$UD)
M`G:7`AY*EQ->#@(ZGI.>Y`&)@+/NG@`3&0X"`S<$]1-9"0*SQ-\!DUFY`;6,
M`A^3%ED`$U\/`K/F-@$^EX(4@9!ZEX(6)I>!DKJ6$Y_B`9/2(@`S;U\`DY0&
M`@,WA/6!D+/"[@&3V;0!L\+"`8(?$YY4`)/?#P(S;CX!/I>"$I/2`@)^EP(>
M%I<37@X".IZ3'^D!$UDI`+/O+P&3$@X"`S<$]I/2`@(S2?\!D]FR`3-)V0""
M'I.64@"3W@X"L^8V`3Z7`AD360D"=I>"%DJ7@9*ZEI.>Y`&)@+/NG@`3F08"
M`S>$]A-9"0*SQ-\!DUFY`;/$Q`$"'Q,>60`37P\",VX^`3Z7@A2!D'J7`AXF
MEQ->#@(ZGA.?X@&3TB(`,V]?`),4#@(#-P3W@9"SPNX!D]FT`;/"T@""'Y.6
M5`"3WP\"L^8V`3Z7@A*3T@("?I>"%A:7@9*ZEI,?Z0$362D`L^\O`9.2!@(#
M-X3WD]("`C-)_P&3V;(!,TG)`8(>$YY2`)/>#@(S;CX!/I<"&1-9"0)VEP(>
M2I<37@X".IZ3GN0!B8"S[IX`$QD.`@,W!/@360D"L\3?`9-9N0&UC`(?DQ99
M`!-?#P*SYC8!/I>"%(&0>I>"%B:7@9*ZEA.?X@&3TB(`,V]?`).4!@(#-X3X
M@9"SPNX!D]FT`;/"P@&"'Q.>5`"3WP\",VX^`3Z7@A*3T@("?I<"'A:7$UX.
M`CJ>DQ_I`1-9*0"S[R\!DQ(.`@,W!/F3T@(",TG_`9/9L@$S2=D`@AZ3EE(`
MD]X.`K/F-@$^EP(9$UD)`G:7@A9*EX&2NI:3GN0!B8"S[IX`$YD&`@,WA/D3
M60D"L\3?`9-9N0&SQ,0!`A\3'ED`$U\/`C-N/@$^EX(4@9!ZEP(>)I<37@X"
M.IX3G^(!D](B`#-O7P"3%`X"`S<$^H&0L\+N`9/9M`&SPM(`@A^3EE0`D]\/
M`K/F-@$^EX(2D]("`GZ7@A86EX&2NI:3'^D!$UDI`+/O+P&3F08"`S>$^I/9
M"0*S0O\!$]FY`;/"P@&"'A.>60"3W@X",VXN`3Z7@A*3T@("=I<"'A:7$UX.
M`K,.QP&3DN0!B8"SXI(`$YD.`@,W!/L360D",\Y?`)-4N0$S3MX``A^3%ED`
M$U\/`L6./I<"'A->#@)ZEX(6@9(3G^D!<I>3V2D`,V\_`3,.UP"#-H3[,\?B
M`3-'UP&"'Y/?#P*3%`X"OI8"%X&0`9/^EI/9M`&3GU0`NI:3'ND!`S<$_!-9
M*0"S[S\!L^XN`?Z6LT_?`;J7@A*"%C/.SP&!DK*7D]("`@(>$]>V`1.65@`3
M7@X"EI=9CO*7$Y?D`8F`LI=%CRZ7,P9O`,:6PIZ"%X&3`A:"%I.5#@("%X&2
M`9*!D0&3'.$4Y1#Q#.V#-H3\@[<#`+6/@488Z9'O@S"!*P,T`2N#-($J`SD!
M*H,Y@2D3`0$L@H#OX&_\77&BX(;D)OQ>Y(`(EX<``(.WYX*#NP<`8X0+"$[T
M4O!6[(-'!0`JBJZ*JHD3!]`#M<=CAN<`@\<9`(4)_?N[B4E!@[0+`+G,2OA:
MZ%Z)$PO0`TZ&TH4FA>_@K\&SAS0!">6#QP<`8X)G`X,TB0`A">WP0GFB>0)Z
MXFI":Z9@!F2B:R:%XG1A88*`,PEY01-9.4"%"2.@*@'.E.&_@4E5MX%$Z;^B
M>0)ZXFK)OW%Q(O$F[4KI`!D&]1=Y```#.:EVDP6$]8,W"0`C//3\@4>JA._@
M+^$5X8,GA/:]9A%G]8]CA><`*6=CFN<`)H6)1>_@3\`3-14`$:`!10,WA/V#
M-PD`N8\!1YGGJG`*=.ID2FE-88*`[^#OZE5QHN%.]8;E@`F7>0``@[D)<(.W
M"0`C//3Z@4<9Q2;]@T<%`*J$F>_J=`,WA/N#MPD`N8\!1V.1!PZN8`YDJGEI
M88*`2OGOX$_D*HEC#`4,4O%*A>_@;[99S8-&-0$3"C4!FX8F_1N&!@"9X@-&
M&@!MT@-'-0$;!R?]FP8'``'K@T<:`)N')_V;A@<`O<_QTB:%5NWOX&^PJHI2
MA>_@[Z^[BJH`B2I6A>_@+[#2AU:&)H>7)@``DX8&C(E%*HKOX,_8DP6$\U*%
M[^`OO/U78PGU`(,GA/2]9A%G]8]CBN<"4H7OX(^V4H7OX"_&2H7J:N_@KZP]
M\4J%[^`ONB:%[^#/L^IT2GD*>@VW@T8J`$&W4H7O\/_NP;\F_4KY4O%6[>_@
MK]CJ=$IY";<!$2;DEW0``(.TQ&`BZ`;L`!"SAT0`B&.79@``DX:&F!=V```#
M-H9?ER4``).%A8+OX`_0DI1"9(A@XF"B9!<G```3!R>[NH:!1Q=V```#-F9:
MER4``).%Y8$%86_@3[A=<:+@)OQ*^$[T4O!6[(`(AN3]<OUWDX>'^Q:1A627
M>@``@[HJ5JJ)+HH3AO3_LP7T`!<5```3!65_@[<*`",\]/J!1^_@SZD;"04`
M8UL@`;,$E$";!_G_OI0#QX3['>^-[Y=W``"#M^=44H;.A9*7B&/OX.^A`S>$
M^X.W"@"YCP%'J>>%8A:1IF`&9.)T0GFB>0)ZXFIA88*`/HG]=Y.'A_NS!/0`
M)H5*AI,%\`+OX"^V1=F7=P``@[?'3\J&)H:2EXACSH7OX*^N=;?OX$_%67&B
M\*;LRNC.Y(;TTN!6_%[T8O"`&)=Y``"#N:E)`\<%`(.W"0`C//3X@4>3!]`#
MKH0JB6,4]P"3A!4`)H7OX"^0JHJ3!43Y2H7O\%_$*HIIS>_@[XYC>54+@RM$
M^1=\```#/*Q&C@L#1PD`RH>3!M`#8P('%&,&UP`#QQ<`A0=]^[N')T$#.@P`
M$X4J`#Z57IKOX.^+(S"J`"G%@S<,``-'"0`3!1D`WI>48Q,&T`,C@.8``>N%
MJ`-'!0`%!:.`YP`UP[:'A0;C&,?^$P?0`R.`YP"%!P/'!`"%!(4'HX_G_G7[
M`S>$^8.W"0"YCP%'X>NF<`9TYF1&::9I!FKB>J)[`GQE88*`@\<$`(4$!0JC
M#_K^X=N#QP0`A00%"J,/^O[]\\&WMH=5MUKX9NQJZ!=\```#/(PY`ST,`(,W
M#0"MS^J'`4J89Z$'TH8%*F7_C283FS8`EW<``(.G)T(7=P``$P>G08WOA4=:
MA1S#[]`__JJ,.<F3&SH`VH;JA5Z&[^`/D2,PG`&;!QH`C@>^G".P#`!">^)L
M0FTC*D3YZ;7:A6J%[^#/GB,PK`"JC!'-DQLZ`-&_@4?YM4%+`4IAOUKX9NQJ
MZ._@KZA">^)L0FT1OY=W``"#M^<P01$BX`;D``B2EP)DHF"(8Y=6``"3AF9H
M%W8```,V9B^7%0``DX5E4D$!;^#/GQUQANRBZ*;D@!#*X$[\4OA6]/ER%WH`
M``,Z2BD6D8,W"@`C//3Z@4?OX`^$_7>3AP?[LP3T``5F*H<%!B:%EQ<``).'
M)U*7%@``DX8F4HE%[^"/F?EWDX>'^C,)]``FA<J%!6;OT%_ZFP0%`(%)8\$$
M`IN*%`!6A>_0'^VJB0G))H;6ALJ%SI3OX`^;(X`$``,WA/N#-PH`N8\!1XGO
MB6(6D>9@3H5&9*9D!FGB>4)ZHGHE88*`[^`OF4$1(N`&Y``(`F2B8$$!);]1
M<:+QINW*Z<[E7O6`&8;UTN%6_5KY8O%F[?UR_7>3AT?Q%I&7>P``@[NK&ZJ)
MKH07%0``$P5E2+,%]`"#MPL`(SST^(%'[_!_ERJ)DP7P`DZ%[]#?_2'!%Q4`
M`!,%Y4;.A>_PW\Q.A0,WA/F#MPL`N8\!1V.>!Q*%8A:1KG`.=.YD3FFN:0YJ
MZGI*>ZI["GSJ;&UA@H`FA>_0?_R7%0``DX6E0^_0O]>JA%W5_7<3AX?YDX>'
M\05KLPKT`),'!/HSC&=!@\<$`#,*Y`#%PV,'"0"FA4J%[]"?[27-)H7OT!_9
MDP?U_Z:7JHR3!O`"8^CT`#&H(X`'`/T78X;T``/'!P#C"=?^)H7OT'_6JHQ.
MA>_0_]5FE04%XW!E]8E%)H=.B)<7``"3A\<[EQ8``).&QCL%9E*%[]"?_M:%
M4H7OT!_B`>F#)XSXO68A9_6/8X'G!)<5``"3A44X`47OT#_,JH3C"P7N@\<$
M`+7S8PP)`(-'"0";AR?]&X<'`)GC`T<9`&';A4R7%```DX2$,D&WA452A>_0
MO]%-_=*%%Q4``!,%I3+O\+^X4H7OT%_K;;WOT/_\`1$BZ";D!NP`$),%\`*J
MA._0O^P9P9,$%0!"9.)@)H6B9`5A;]!_Z#EQ(OA.[`;\)O1*\(``_7*7>0``
M@[DI_Q:1@[<)`",T]/R!1UG)@T<%`"J)V<?OT%_&$P85`(5GJH1CZ,<*_7>3
MAX?\,P?T`,J%.H7OT'_6DX?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#QP<`
MXPG7_OUWDX>'_+,$]``FA9,%\`+OT!_C%<EC[J0$_7>3AX?\,P7T`._0W]X#
M-X3\@[<)`+F/`4>AYX5B%I'B<$)THG0">>)I(6&"@`,WA/R#MPD`N8\!1X7G
MA6(6D>)P0G2B=`)YXFD7%0``$P7%'R%A;]`_VB,`!0!5MP%%?;?OT%_K.7$B
M^";T2O!.[(``!OP7>0```SDI\),$1/R#-PD`(S3T_(%'EWD``(.Y2?"FA1<5
M```3!24?[_"/ZQ7%`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3
M!84<[_#OZ&']EWD``(.Y*>RFA1<5```3!04<[_!OYQ7%`R=$_(.W"0`.![J7
MF&>8XV73F&NA!YCC;?^FA1<5```3!649[_#/Y&']EWD``(.Y">BFA1<5```3
M!648[_!/XQ7%`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3!<45
M[_"OX&']EWD``(.YZ>.FA1<5```3!445[_`OWQ7%`R=$_(.W"0`.![J7F&>8
MXV73F&NA!YCC;?^FA1<5```3!:42[_"/W&']EWD``(.YR=^FA1<5```3!:41
M[_`/VQ7%`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3!04/[_!O
MV&']EWD``(.YJ=NFA1<5```3!84.[_#OUA7%`R=$_(.W"0`.![J7F&>8XV73
MF&NA!YCC;?^FA1<5```3!>4+[_!/U&']EWD``(.YB=>FA1<5```3!>4"[_#/
MTA7%`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3!44`[_`OT&']
MEWD``(.Y:=.FA1<5```3!44'[_"OSA7%`R=$_(.W"0`.![J7F&>8XV73F&NA
M!YCC;?^FA1<5```3!:4$[_`/S&']EWD``(.Y2<^FA1<5```3!24$[_"/RA7%
M`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3!84![_#OQV']EWD`
M`(.Y*<NFA1<5```3!04![_!OQA7%`R=$_(.W"0`.![J7F&>8XV73F&NA!YCC
M;?^FA1<5```3!67^[_#/PV']EWD``(.Y"<>FA1<5```3!67S[_!/PA7%`R=$
M_(.W"0`.![J7F&>8XV73F&NA!YCC;?^FA1<5```3!<7P[_"OOV']IH47%0``
M$P5%^N_PK[ZJA1G%%Q4``!,%1??O\,_TIH47%0``$P7E^>_PS[RJA1G%%Q4`
M`!,%9?KO\._RIH47%0``$P6%^N_P[[JJA17-%Q4``!,%!>KO\`_Q`S>$_(,W
M"0"YCP%'J>-"=.)PHG0">>)IEQ4``).%Q?D7%0``$P7%[2%A;_`O[J:%%Q4`
M`!,%Q?;O\"^VJH5IT1<5```3!<7M[_!/[%6_[]#_L'EQ(O`F[``8!O27=```
M@[0$MI,%1/T7%0``$P5%ZYQ@(SST_(%'[_`OL@7%@T<%``%%B<>3AP?],S7P
M``,WA/V<8+F/`4>!ZZ)P`G3B9$5A@H`!1>6W[]!?JQUQ(N@&[``0%W,```,S
M`[4JC@,U`P`3`X0`#.00Z!3L<H88\!=^```#/LZN'/0C.`0#(SP4`YJ&B46#
M-PX`(S3T_H%'(S!D_N_0C_X3!?`/[]`/^AUQHNA._%+X5O2&[*;DRN!:\%[L
M@!#!<I=Z``"#NDJJ%I$)1H.W"@`C-/3Z@4>!12J*[]"_BI,)]?\3U_E#09.S
MA^D`PA?!DYF/LXGY0&/,"0C!=Y.'!_HS"?0`?5N=2P%&SH52A>_0?X=C#64)
M068A!LJ%4H7OT'^3`25C!V4'8_^K!&$5LP2I`&/V)`&!J/T48^8D!2%&EW4`
M`).%Q:DFA>_0OX!M]<%WDX<'^J*7,X7T0$Z5`S>$^H.W"@"YCP%'L>_!8A:1
MYF!&9*9D!FGB>4)ZHGH">^)K)6&"@,%WOIGCG_GV?57YMP,WA/J#MPH`N8\!
M1X7G%Q4``!,%1=WO\-_J`S>$^H.W"@"YCP%'F><7%0``$P6EVN_P/^GOT/^3
M01$&Y"+@``COT"_A[]#_BQ'!"&&B8`)D00&"@#EQ(OA*\$[L@``&_)=Y``"#
MN2F7*HF3!43\%Q4``!,%1=B#MPD`(S3T_(%'[_`/DQG%)O2#1P4`JH2-YZ)T
M`S>$_(.W"0"YCP%'RH47%0``$P4EU:WK0G3B<`)YXFDA86_P[\9*A5+H[]!O
MVBJ*)H7OT._9*IH)"E*%[]!/VB:(2H>7%P``DX='OU*&EQ8``).&IK^)1:J$
M[]!_@@,WA/R#MPD`N8\!1YWC0G1":N)P`GGB:::%HG07%0``$P5ESB%A;_#/
MP";T4NCOT%^%[]`?A4EQEW<``).')Y*B\LKJ@!K.YM+BAO:F[@.XAP,#OP<!
M@[Z'`0.^!P(#LX<"@[@'`Q,)Q.H7>@```SJ*AZJ)%Q8``!,&9LJ7%@``DX9F
MLQ<7```3!^?)EQ<``).'Y\DC.`3QRH47%0``$P4%L@,X"@`C/`3Y`4@C,`3N
M(S0$[",TY.\C.-3O(SS$[R,P9/`C-!3Q(SC$[",\U.PC/.3J(S#T[._@G_X1
MQ8-'!0"JA&.=!R)6_EKZ7O9B\N_0+\?OT._Q8PL%&`,[!0!C!PL86H7OT,_&
MDQ05`(4$)H7OT`_'`T<+`*J+)HRJB@7/EQ8``).&AL$FAHE%7H7OT"_O!0OB
MAF-SG`"FAK.'ED")!V/SUP"VAP-'"P#Y%)6,OI2)"W'W$PN$[A<5```3!66T
M*:`#-8L`(0L-P<J%[^`?]:J$9=F#1P4`[=?OX/_^==$FA>_0S]VJA!7A$PL$
M[8,T"P")S(/'!`!CAP<.)H7OX+_\<>F#-(L`(0OM]":%[]`/O"J+5H7OT(^[
M.PNK`!L+2T!:A>_0K[N7%P``DX=GH=:()H=:AA<8```3"(BVEQ8``).&AK:)
M1:J+[]!/XUZ%DP4`'._0K]3]5V,8]0#OT`^Z'$%%1V.:YPYJZA,-A/'JA5Z%
M[]"OV*J$`>F#)X3RO6819_6/8XGG"I=G``"#M\=O@[8)`(AC7H<7%@``$P;&
MM8E%[]"OVU)M@4H#-X3Y@S<*`+F/`4=CDP<PMG`6=%)[LGL2?/9D5FFV:19J
M5H7R>G5A@H`FA>_0;\ZJA"$+XP<%\"6W@405MY,$A.N(8!G)RH7OX)_B`<6#
M1P4`E>.(9*$$??4U1>_0;ZTU3*J+JHKBA!<;```3"ZNE$P<P!;F][]#/R2J+
MH01QT>_0+ZJ3%!4`A00=O8,J!//OT"^HXY6J](,GA/)F[A,'`!R3]_<?8XCG
M!/)L#;\79P```S?'8H.V"0`(8Q<6```3!N:D7H>)1>_0K\X-O^_P?\0#-X3Y
M@S<*`+F/`4=CG@<B%G2V<%9IMFD6:B:%]F1U86_0#\):A>_0KZ/*A:J*%Q4`
M`!,%):KOX)_6JH5C#`40`[4)`._P[[FJC&,%!1!FA>_0#Z`;#`4`C4=CV(<#
M$P7,_V:5EQ4``).%1:?OT$^R">V11V,#_!B;![S_YI<#QP<`DP?P`F,*]Q;*
MA1<5```3!46)[^"_T&G!@T<%`-7/$P<``V.+YPJ7%0``DX4%D1<5```3!06'
M[_"/A>_03ZPJB%Z'6H96A9<8``"3B(BPEP<``).'!W^7%@``DX8&HXE%[]#O
MP7U9Q4D7'```$PQLKA6H[]#/F!Q!8YTW`^_0+ZB%)"J(8N"FB%Z'6H96A9<'
M``"3AP=[EQ8``).&!J")1>_0[[V3!0`<5H7OT$^OXP(E_5Z%[]"OK-:%%P4`
M`!,%Q77OX-_\5H7O\)^O\FQ2;?&[@[P)`-V]9H6!1>_0+\$JB3'1[_#_F:J)
MXTX%\I,%9?\!1DJ%[]"/IA,,!.OBA4J%&4;OT*^RF4=C'?4(`R<$Z[='04.3
MAP<PXQ;W\`-73`"19Y.'AU3C'_?NDX7I_`%&2H7OT*^B2H7JA1,&@`+OT.^N
MDP>``F,>]01JB%J&EQ@``).(Z)^7!P``DX=G;EZ'EQ8``).&1I&)15:%(P`$
M]._0S[`UOX.YB0#CA@GH3H7OT,^$C4?C\*?H<15.E9<5``"3A>6,[]!OE^,6
M!>;.C)VU`S>$^8,W"@"YCP%'B>L7%0``$P5%B^_P7X=F[FKJ[]#/L5;^6OI>
M]F+R9NYJZN_0S[!=<2;\EV0``(.T1#FBX$[T4O"&Y$KX5NR`"+.'1``#N0<`
M$PI$^Y=I``"#N2DT@T<)"]*%%P4``!,%16<#MPD`(SSD^@%'HPCY"N_@WZ\9
MQ0-'!0"3!Q`#8P#W%N_PS[^SAT0``[D'`$J%C48%1I<5``"3A:6&[\`__RJ)
M!<4<:3.'1``(8XQC%Q8``!,&AH7OP)_^@S<)`8QCW$43EY<"8T@'$K.'1`"(
M8XU&!4:7%0``DX6E@^_`/_LJB9=J``"3BDHW'<'2A1<%```3!858[^!_IX,W
M"0$JAHQC8P,%#K.'1`"(8^_`/_FSAT0``[D'``5&EP4``).%Q7]*A>_`O^RJ
MA1<6```3!D:`2H7OP+_VDI2<8-*%%P4``!,%A5*CB`<*[^`_HB.XJ@"JA"7!
MDP4`'":%[]`OB1L'%0"%1V/WYP+%1V,$]0(#-X3[@[<)`+F/`4?9XX.WB@"J
MAB:&C&,7!0``$P5E?>_0[XP#-X3[@[<)`+F/`4>MXZ9@!F3B=$)YHGD">N)J
M86&"@`.UB@#O\+^2([BJ`*J$4?D#-X3[@[<)`+F/`4>-ZQ<%```3!45V[]!/
MB(-'%0#CA@?J<;V#MXH`+H6,8^_@_\$QO[.'1`"(8^_0+X/IM>_0SY(Y<2+X
M)O1*\(``!OR79```@[3$%RJ)DP5$_!<%```3!>5,G&`C-/3\@4?OX-^3"<V#
M1P4`D<L3!P`#8X?G`&,%"0"#1PD`B>\#-X3\G&"YCP%'N>_B<$)THG0">2%A
M@H!*A4[L[_`ODI,%\`*JB>_`O_P9P9,)%0!.A>_`__@11I<%``"3A856[\`?
MU1G!XFEEOP,WA/R<8+F/`4>9ZT)TXFGB<*)T2H4">2%A;^`_G4[L[]!OAT$1
M(N`&Y``($P4`"._`?]872````SBH1[=V74PW=^EAA@:W)45G-U8R$`8'DX;F
MSY.%%3`3!F9'$P<''Q3I(S0%`B,X!0(C+`4&#.$C-`4!$.T8\:)@`F1!`8*`
M77&BX$KX3O16[%KHAN0F_%+P@`@8=9,7-@"RB;J7$'F"%X&3,[?G`"J)D];9
M`2A=.I8SA\8`(S3Y`B,XZ0(NBY,*B0,U[9,'\`-CVC<%&]II`%[DFPOZ_V+@
M&@H3G`L"$UP,`EJ:VH2FA1,&``16A>_`?]N3A`0$2H7OT*^EXY5$_[L+<$&;
MFVL`&@R;B0G\$PL+!+N).P%BFZ)K`FS:A5:%3H;OP#_8(RPY!Z9@!F3B=$)Y
MHGD">N)J0FMA88*`DP<`!(F?OH1CR_D"&XH$`),*B0-2AE:5VH7OP-_4@R>)
M!Q,'``2EGR,L^0;CD.?\2H6[B9E`4IOOT,^=J;?.A/&W77&BX";\2OA2\%;L
M7N2&Y$[T6NB`"(.YA0*#UH4"`]<%`Y/7.0"3BX4#D_?W`Q/:A@"36H<`FY:&
M`!L7AP`SAOL`KH0S:MH`DP4`^+/JZ@`#NP0#A2<C`+8`0AK"&A,&@`,JB1-:
M"@,SA?L`D]H*`V-6]A`3!P`$NP?W0!%'8_#G$@E'8_3G$&.?!PXFA>_03Y1>
MA1,&@`.!1>_`O]V3UXD!$U>+`9/9"0$36PL!(YE4!R.;1`>CB&0'(XKT!J.*
M-`<FA2.(Y`;OT*^0G&`FA>&#(P#Y`)Q@P8.C`/D`G&"A@R,!^0"<8*,!^0"<
M9.&#(P+Y`)QDP8.C`OD`G&2A@R,#^0"<9*,#^0"<:.&#(P3Y`)QHP8.C!/D`
MG&BA@R,%^0"<:*,%^0"<;.&#(P;Y`)QLP8.C!OD`G&RA@R,'^0"<;*,'^0"<
M<.&#(PCY`)QPP8.C"/D`G'"A@R,)^0"<<*,)^0`&9*9@XG1">:)Y`GKB:D)K
MHFMA86_`W\,=GH%%[\!?SRF_(P`%``FW(P`%`*,`!0#Y%SJ5XXH'[NVW(P`%
M`*,`!0`C`04`HP$%`/$7.I4)1^/JY^S1OT$1(N`&Y``(`F2B8)=F``"#MN;A
M00%OP%^O`0`"```````E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O<V5L9B]E
M>&4``&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%35``
M`````````%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S
M``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!
M3@````````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'
M3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!
M4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@``````````,0````````!L<V5E:R!F86EL960`````<F5A9"!F86EL960`
M`````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"]T;7``````55-%4@````!5
M4T523D%-10``````````)3`R>`````!P87(M`````"5S)7,E<R5S````````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R`````'-H
M;W)T(')E860````````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,``````````!@`````````<&5R;``````P````
M`````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8S````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``````````"UE````````+2T```````!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%2
M7TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D[
M"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F
M<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@
M/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD
M7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@
M-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O
M<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@
M(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H
M:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H
M+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@
M*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR
M971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T
M=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L
M("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY
M("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN
M+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M
M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@
M)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH
M)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O
M9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H
M)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B![
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D
M(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R
M92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P
M;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B10
M05)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*
M?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O
M<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@
M;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I
M.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F
M;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S
M:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY
M("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R
M;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O
M=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO
M9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I
M;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A
M<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)
M3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L
M96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A
M9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*
M<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N
M86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O
M9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I
M;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@
M4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@
M>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q
M=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[
M7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,
M14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D
M8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA
M;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE
M+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD
M8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]
M"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H
M)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]
M("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM
M>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D
M9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N
M=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D
M=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM
M?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D
M14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D
M7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*`%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````B:O-[P``
M``!P97)L>'-I+F,``````````$-!0TA%```!&P,[[````!P```#HB___;`<`
M`)2-__\$`0``AH[__Q@!```&I/__5`$``+*D___$`0``'J7___P!``!(IO__
M:`(``*BF__^4`@``>*?__]@"``!*J?__3`,``("I__]T`P``.JK__[@#``!*
MJO__X`,``/ZK__\T!```)JS__V`$```8K?__K`0``+ZP___H!```&+'__Q@%
M``!LL?__.`4``(ZR__^`!0``JK+__Z@%``!\L___$`8``,"X___,!@``H+K_
M_Q`'``!6N___K`<``+*[___4!P``M+S__R0(``!NOO__<`@````````0````
M``````-Z4@`!?`$!&PP"`!`````8````B(S__R(`````!P$`.````"P```!F
MC?__@!4```!$#L`%1(@$0@P(`%Z!`HD&D@B3"@,^%0K!1,@,`L`%1,E$TD33
M1`X`0@L`;````&@```"JHO__K`````!"#E!(B`2!`HD&EQ)"#`@`6I,*E`R5
M#F:2")80:-)"TT+40M5"UD+!0L@,`E!"UT3)0@X`0@T(@0*(!(D&D@B3"I0,
ME0Z6$)<24M+61-/4U423"I0,E0Y"TT+40M4``#0```#8````YJ+__VP`````
M0@ZP`4:(!(D&D@A"#`@`2H$"`DH*P4+(#`*P`4+)0M)"#@!""P``:````!`!
M```:H___*@$```!"#M`!1H@$DPJ!`D(,"`!:B09&R5+!0L@,`M`!0M-"#@!"
M#0B!`H@$B0:3"D*2"$R4#`)"E0X"7-54"LE"TD+40@M&E0Y(R=+4U4B)!I((
ME`R5#D34U4+)0M(`*````'P!``#8H___8`````!"#B!"B09,B`2!`D(,"`!F
MR`P"($3!0LE>#@!`````J`$```RD___0`````$(.4$R(!(D&D@B3"I0,E0Y"
M#`@`5H$"`F(*#`)00L%"R$+)0M)"TT+40M5"#@!""P```'````#L`0``F*3_
M_](!````0@YP4H@$B0:2"),*@0*4#)4.EQ*8%$(,"``"W@K!0L@,`G!"R4+2
M0M-"U$+50M="V$(.`$(+<)80F1::&`)>"M9"V4+:1@M6UMG:1)80F1::&$;6
MV=I&EA"9%IH81M9"V4+:)````&`"``#VI?__-@````!*#A!$B`2!`D(,"`!$
MR`P"$$+!7`X``$````"(`@``!*;__[H`````0@Y@1H$"B`2)!D(,"`!*D@B3
M"I0,E0X"C@H,`F!"P43(0LE"TD+30M1"U4(.`$(+````)````,P"``!ZIO__
M$`````!"#A!$B`2!`D(,"`!"R`P"$$+!0@X``%````#T`@``8J;__[0!````
M0@[P`4J(!(D&D@B3"I<20@P(`&"!`I0,E0Z6$)@4F18"3@H,`O`!0L%"R$+)
M0M)"TT+40M5"UD+70MA"V4(.`$(+`"@```!(`P``PJ?__R@`````0@X@1H@$
MB0:!`D(,"`!2R`P"($+!1,E"#@``2````'0#``"^I___\@````!"#D!*B`23
M"H$"B0:2"$(,"``"G@H,`D!"P4+(0LE"TD+30@X`0@M2"@P"0$+!0LA"R4+2
M0M-*#@!$"S@```#``P``9*C__Z8#````0@Y`2(@$B0:2"),*0@P(`$J!`@-.
M`PK(#`)`0L%"R4+20M-2#@!$"P```"P```#\`P``SJO__UH`````0@XP1(@$
MB09"#`@`2H$">`K!0L@,`C!"R4(.`$(+`!P````L!```^*O__U0`````0@Y@
M1(@4@1)"#`A`````1````$P$```LK/__(@$```!"#F!2B`23"I0,E0Z!`HD&
MD@B6$)<20@P(``*R"@P"8$+!0LA"R4+20M-"U$+50M9"UT(.`$(+)````)0$
M```&K?__'`````!"#A!$@0*(!$(,"`!.P4+(#`(00@X``&0```"\!```^JS_
M_](`````0@Y`1H@$D@B3"D(,"`!B@0),B09&R5K(#`)`0L%"TD+30@X`1`T(
M@0*(!(D&D@B3"D24#`)$R`P"0$+40L%"TD+31,E*#@!$#0B!`H@$D@B3"D2)
M!I0,N````"0%``!DK?__1`4```!"#O`"3(@$D@A"#`@`9),*E`R!`HD&`H:5
M#I80EQ*8%`,@`9H8`C[:5`K!0L@,`O`"0M9"UT+80LE"TD+30M1$U4(.`$(+
M`F*:&%J9%D;90MI@U=;7V%;(#`+P`D+!0M)"TT+41,E"#@!$#0B!`H@$B0:2
M"),*E`R5#I80EQ*8%)D6FA@#+`$*V4+:0@L#[`#9VD29%IH81-76U]C9VDR5
M#I80EQ*8%)D6FAA`````X`4``.RQ___@`0```$(.4$*)!E2(!),*E`R!`I((
ME0Y"#`@``V0!"L%"R`P"4$+)0M)"TT+40M5"#@!""P```%@````D!@``B+/_
M_[8`````0@Y`1H@$B0:2"$(,"`!@@0)L"L%"R`P"0$+)0M)"#@!""T23"FP*
MTT(+3L@,`D!"TT+!0LE$TD(.`$0-"($"B`2)!I((0I,*````/````(`&``!T
MA/__K`$```!"#F!&@0*(!)((0@P(`$:)!I,*E`P#+`$*P4+(#`)@0LE"TD+4
M1--"#@!""P```"0```#`!@``HK/__UP`````0@X01(@$@0)"#`@``D[!0L@,
M`A!"#@!,````Z`8``-:S__\"`0```$(.4%"(!)((DPJ5#I80@0*)!I0,0@P(
M``)`EQ)&F!0"0M="V%`*P4+(#`)00LE"TD+30M1"U4+60@X`0@L``$@````X
M!P``B+3__[H!````0@Y04H@$B0:2")0,E0Z7$H$"DPJ6$$(,"``#4`$*R`P"
M4$+!0LE"TD+30M1"U4+60M="#@!$"P`````D````A`<``/:U__\:`````$(.
M$$2(!($"0@P(`$+(#`(00L%*#@````````0````0`````0```$=.50``````
M!`````\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`0````````#Y`@````````$`````````!`,````````!``````````X#````
M````'0````````"X!````````"``````````>*L````````A``````````@`
M````````&0````````"`JP```````!L`````````"``````````:````````
M`(BK````````'``````````(`````````/7^_V\`````\`(````````%````
M```````.````````!@````````"(!`````````H`````````VP0````````+
M`````````!@`````````%0````````````````````,`````````L*T`````
M```"`````````%@%````````%``````````'`````````!<`````````2!8`
M```````'``````````@4````````"`````````"8!P````````D`````````
M&``````````>``````````@`````````^___;P`````!```(`````/[__V\`
M````J!,```````#___]O``````(`````````\/__;P````#<$@```````/G_
M_V\`````#0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/__________``````````"@&P```````*`;````````H!L```````"@
M&P```````*`;````````H!L```````"@&P```````*`;````````H!L`````
M``"@&P```````*`;````````H!L```````"@&P```````*`;````````H!L`
M``````"@&P```````*`;````````H!L```````"@&P```````*`;````````
MH!L```````"@&P```````*`;````````H!L```````"@&P```````*`;````
M````H!L```````"@&P```````*`;````````H!L```````"@&P```````*`;
M````````H!L```````"@&P```````*`;````````H!L```````"@&P``````
M`*`;````````H!L```````"@&P```````*`;````````H!L```````"@&P``
M`````*`;````````H!L```````"@&P```````*`;````````H!L```````"@
M&P```````*`;````````H!L```````"@&P```````*`;````````H!L`````
M``"@&P```````*`;````````H!L```````"0JP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````I005(N<&T*````````````````````````
M````````````````````````````````````````````````````````````
M`$=#0SH@*$=.52D@,30N,BXQ(#(P,C4P,C`W`$%E````<FES8W8``5L````$
M$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?
M>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P```N<VAS
M=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`
M+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+G!R96EN:71?87)R87D`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT`"YR:7-C=BYA='1R:6)U=&5S````````````````````````````
M```````````````````````````````````````````````````````````+
M````!P````(`````````J`(```````"H`@```````"0`````````````````
M```$````````````````````'@````$````"`````````,P"````````S`(`
M```````A`````````````````````0```````````````````"8```#V__]O
M`@````````#P`@```````/`"````````E`$````````$``````````@`````
M```````````````P````"P````(`````````B`0```````"(!````````'@)
M````````!0````(````(`````````!@`````````.`````,````"````````
M```.``````````X```````#;!````````````````````0``````````````
M`````$````#___]O`@````````#<$@```````-P2````````R@`````````$
M``````````(``````````@````````!-````_O__;P(`````````J!,`````
M``"H$P```````&``````````!0````(````(````````````````````7```
M``0````"``````````@4````````"!0```````!``@````````0`````````
M"``````````8`````````&8````$````0@````````!(%@```````$@6````
M````6`4````````$````%`````@`````````&`````````!K`````0````8`
M````````H!L```````"@&P```````+`#```````````````````0````````
M`!``````````<`````$````&`````````%`?````````4!\```````"@,@``
M````````````````!````````````````````'8````!`````@````````#P
M40```````/!1````````=T$```````````````````@`````````````````
M``!^`````0````(`````````:),```````!HDP```````.P`````````````
M```````$````````````````````C`````$````"`````````%B4````````
M6)0```````"L!P``````````````````"````````````````````)8````'
M`````@`````````$G`````````2<````````(`````````````````````0`
M``````````````````"D````$`````,`````````>*L```````!XJP``````
M``@````````````````````(``````````@`````````LP````X````#````
M`````("K````````@*L````````(````````````````````"``````````(
M`````````+\````/`````P````````"(JP```````(BK````````"```````
M``````````````@`````````"`````````#+````!@````,`````````D*L`
M``````"0JP```````"`"````````!0`````````(`````````!``````````
MU`````$````#`````````+"M````````L*T```````!0`@``````````````
M````"``````````(`````````-D````!`````P``````````L`````````"P
M````````4`````````````````````@```````````````````#?````"```
M``,`````````4+````````!0L````````"@````````````````````(````
M````````````````Y`````$````P````````````````````4+`````````;
M`````````````````````0`````````!`````````.T````#``!P````````
M`````````````&NP````````9@````````````````````$`````````````
M```````!`````P````````````````````````#1L````````/\`````````
8```````````!````````````````````
